# ebooklet

<p align="center">
    <em>Organise all your data in key/value books and sync them with S3.</em>
</p>

[![build](https://github.com/mullenkamp/ebooklet/workflows/Build/badge.svg)](https://github.com/mullenkamp/ebooklet/actions)
[![codecov](https://codecov.io/gh/mullenkamp/ebooklet/branch/master/graph/badge.svg)](https://codecov.io/gh/mullenkamp/ebooklet)
[![PyPI version](https://badge.fury.io/py/ebooklet.svg)](https://badge.fury.io/py/ebooklet)

---

**Documentation**: <a href="https://mullenkamp.github.io/ebooklet/" target="_blank">https://mullenkamp.github.io/ebooklet/</a>

**Source Code**: <a href="https://github.com/mullenkamp/ebooklet" target="_blank">https://github.com/mullenkamp/ebooklet</a>

---

## Introduction

EBooklet is built upon Booklet to sync booklet files with remote S3 buckets. The local booklet files can be used independently of EBooklet.


## License

This project is licensed under the terms of the Apache Software License 2.0.
